This directory features test cases for modules that **DO NOT** require the
Gramex server to run. Any test case in `../tests/` will start Gramex. No test
case in this directory will start Gramex. (These are faster to run.)
